from flask import Flask, request, render_template_string
import base64

app = Flask(__name__)

template_text = """<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Hash Decoder</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background: linear-gradient(to right, #4facfe, #00f2fe);
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            padding: 20px;
            width: 400px;
            max-width: 90%;
        }

        .container h2 {
            text-align: center;
            margin-bottom: 20px;
            color: #333;
        }

        .radio-group {
            text-align: center;
        }

        .radio-group label {
            margin: 0 10px;
            font-size: 14px;
        }

        .radio-group input[type="radio"] {
            margin-right: 5px;
        }

        textarea {
            width: 100%;
            height: 150px;
            margin: 15px 0;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            resize: none;
            font-size: 14px;
            box-sizing: border-box;
        }

        textarea:focus {
            outline: none;
            border-color: #4facfe;
            box-shadow: 0 0 5px rgba(79, 172, 254, 0.5);
        }

        .btn {
            display: block;
            width: 100%;
            padding: 10px;
            font-size: 16px;
            color: #fff;
            background-color: #4facfe;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s ease;
        }

        .btn:hover {
            background-color: #3a8ede;
        }

        .footer {
            margin-top: 30px;
            text-align: center;
            font-size: 14px;
            color: #666;
            margin-top: 20px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>Hash Decoder</h2>
        <form>
            <div class="radio-group">
                <label>
                    <input type="radio" name="hash" value="hex" checked> Hex
                </label>
                <label>
                    <input type="radio" name="hash" value="base64"> Base64
                </label>
            </div>
            <textarea id="hash_hash" name="hash_text" placeholder="请输入Hash值...">PLACEHOLDER_1</textarea>
            <button type="submit" class="btn">解码</button>PLACEHOLDER_2
        </form>
        <div class="footer">自豪的采用 flask + jinja2 实现</div>
    </div>
</body>

</html>
"""

@app.route('/')
def index():
    # 如果是 GET 请求，判断是否有get参数

    hash_method = request.args.get('hash')
    if hash_method in ["hex", "base64"]:
        hash_text = request.args.get('hash_text')
        if hash_text:
            if hash_method == "hex":
                try:
                    decoded_text = bytes.fromhex(hash_text).decode()
                except:
                    decoded_text = "%s cannot be decoded by hex" % hash_text
            else:
                try:
                    decoded_text = base64.b64decode(hash_text).decode()
                except:
                    decoded_text = "%s cannot be decoded by base64" % hash_text
            return render_template_string(template_text.replace("PLACEHOLDER_1", hash_text).replace("PLACEHOLDER_2", "<textarea readonly>%s</textarea>" % decoded_text))
    return render_template_string(template_text.replace("PLACEHOLDER_1", "").replace("PLACEHOLDER_2", ""))


if __name__ == '__main__':
    app.run()